@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use Data::Dumper;
 
-our $VERSION = "0.04";
+our $VERSION = "0.06";
 
 require Exporter;
 our @ISA = qw/Exporter/;
@@ -52,6 +52,7 @@ sub key {
     my $self = shift;
     my @keys = @_;
 
+    return $self->{keys} unless(scalar @keys);
     push @{$self->{keys}}, [@keys];
     $self;
 }
@@ -112,15 +113,40 @@ __END__
 
 =head1 NAME
 
-Data::Nest - It's new $module
+Data::Nest - nest array of hash easily. and calculate optional measurements corresponding to results of nest.
 
 =head1 SYNOPSIS
 
     use Data::Nest;
 
+    my $nest = Data::Nest->new();
+    $nest->key("mykey");
+    my $nested = $nest->entries([
+      {mykey => 1, val => 1},
+      {mykey => 2, val => 2},
+      {mykey => 1, val => 3},
+      {mykey => 1, val => 4},
+      {mykey => 2, val => 5},
+    ]);
+    print Dumper $nested;
+
+    # [
+    #   {key => 1, values => [
+    #     {mykey => 1, val => 1},
+    #     {mykey => 1, val => 3},
+    #     {mykey => 1, val => 4},
+    #   ]},
+    #   {key => 2, values => [
+    #     {mykey => 2, val => 2},
+    #     {mykey => 2, val => 5},
+    #   ]},
+    # ]
+
 =head1 DESCRIPTION
 
-Data::Nest is ...
+Data::Nest is array of hash nesting utility.
+Easily add measurements like "sum", "sumsq", "average",....
+It's easy to nest data for prepareing data mining and data visualization.
 
 =head1 LICENSE
 
